/*
 * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.mobile.api.facade.models;

import com.openexchange.mobile.api.facade.connectors.responses.mtos.AttachmentMto;

import lombok.AllArgsConstructor;
import lombok.Data;

@Data
@AllArgsConstructor
public class Attachment {

    public enum Disposition {
        NONE("none"),
        ATTACHMENT("attachment"),
        INLINE("inline");

        private String value;

        Disposition(String value) {
            if (value == null) {
                throw new IllegalArgumentException("Disposition enum needs a value");
            }
            this.value = value;
        }

        public static Disposition from(String value) {
            for (Disposition disposition : values()) {
                if (disposition.value.equalsIgnoreCase(value)) {
                    return disposition;
                }
            }
            return NONE;
        }

        public String getValue() {
            return value;
        }
    }

    private final String id;

    private final Disposition disposition;

    private final String contentType;

    private final Integer size;

    private String content;

    private final boolean truncated;

    private final String filename;

    private final String cid;

    private String downloadUrl;

    public Attachment(AttachmentMto attachmentMto) {
        this.id = attachmentMto.getId();
        this.disposition = Disposition.from(attachmentMto.getDisposition());
        this.contentType = attachmentMto.getContentType();
        this.size = attachmentMto.getSize();
        this.content = attachmentMto.getContent();
        this.truncated = attachmentMto.isTruncated();
        this.filename = attachmentMto.getFilename();
        this.cid = attachmentMto.getCid();
    }

}
